#!/bin/ksh
#
#
# Remplacer # par # dans les commandes
#
#
cat << @EOFF
#
#===============================
#-- TSM info
#===============================
#
#--- Info sur DB
select StAr from DB

#--- TSM database utilization (%)
SELECT pct_utilized FROM db
SELECT avail_space_mb,capacity_mb, pct_utilized, max_pct_utilized,last_backup_date FROM db

#--- TSM log recovery utilization (%)
SELECT pct_utilized FROM log

#--- TSM clients version
SELECT node_name, VARCHAR(client_version)||#.#||VARCHAR(client_release)||#.#||VARCHAR(client_level)||#-#||VARCHAR(client_sublevel)"Client Version.release.level" FROM nodes

#--- tables ayant un index unique
select TABSCHEMA,TABNAME,REMARKS from TABLES where UNIQUE_INDEX =TRUE

#
#===============================
#-- PATHS et DRIVES
#===============================
#
#--- union table paths et drives
select SOURCE_NAME,DESTINATION_NAME,DESTINATION_TYPE,a.LIBRARY_NAME,DRIVE_SERIAL,DEVICE,ELEMENT,b.drive_name,ACS_DRIVE_ID from paTHS a,DRIVES b where a.destination_name=b.drive_name order by element,device

#--- table paths 
select SOURCE_NAME,DESTINATION_NAME,DESTINATION_TYPE,LIBRARY_NAME,NODE_NAME,DEVICE from PATHS

#
#===============================
#-- NODES
#===============================
#
#--- Number of nodes per platform
SELECT platform_name,COUNT(StAr) as "Nombre" FROM nodes GROUP BY platform_name

#--- Nodes without associated schedules
SELECT node_name FROM nodes WHERE node_name NOT IN (SELECT node_name FROM associations)

#--- Nodes with associated schedules
SELECT node_name FROM nodes WHERE node_name IN (SELECT node_name FROM associations)

#--- Number of nodes associated per schedules
SELECT domain_name, schedule_name, count(*)"Nombre" FROM associations GROUP BY domain_name, schedule_name

#--- Sessions Nodes using tapes (drives)
SELECT client_name, session_id, start_time, state, bytes_sent, bytes_received, input_vol_access, output_vol_access FROM sessions WHERE ( input_vol_access is not NULL OR output_vol_access is not NULL )

#--- Performance of nodes sessions
SELECT client_name,session_id, current_timestamp-start_time AS ElapTime, commmethod, state, CAST(bytes_sent/1024/1024 AS DEC(8,2)) AS "MB_Sent", CAST(bytes_received/1024/1024 AS DEC(8,2)) AS "MB_Rcvd", cast((cast(bytes_sent as dec(18,0))/cast((current_timestamp-start_time) seconds as decimal(18,0))) / 1024 / 1024 AS DEC (18,2)) AS "Sent_MB/s",  cast((cast(bytes_received as dec(18,0))/cast((current_timestamp-start_time) seconds as decimal(18,0))) / 1024 / 1024 AS DEC (18,2)) AS "Rcvd_MB/s" FROM sessions WHERE session_type=#Node#

#
#===============================
#-- MANAGEMENT CLASS
#===============================
#
#--- Retention des MGMT
select a.DOMAIN_NAME,SET_NAME,cLASS_NAME,BACKRETENTIOn from DOMAINS a, MGMTCLASSES b where a.dOMAIN_NAME = b.DOMAIN_NAME order by CLASS_NAME

#
#===============================
#-- Backup Archive
#===============================
#
#--- Liste des Backups DB 
select VOLUME_NAME,LOCATION,VOLTYPE,upd_date from DRMEDIA where VOLTYPE = #DBBackup#
select DATE_TIME,VOLUME_NAME,LOCATION from VOLHISTORY where VOLUME_NAME in ( select VOLUME_NAME from drmedia where VOLTYPE =#DBBackup# ) and LOCATION <>## order by DATE_TIME desc

#--- Periode de retention DOMAIN_NAME SET_NAME CLASS_NAME BACKRETENTION
select a.DOMAIN_NAME,SET_NAME,cLASS_NAME,BACKRETENTIOn from DOMAINS a, MGMTCLASSES b where a.dOMAIN_NAME = b.DOMAIN_NAME and SET_NAME not in (#ACTIVE#,#STANDARD#) order by CLASS_NAME

#--- Number of files per client
SELECT node_name, SUM(num_files) FROM occupancy GROUP BY node_name

#--- Space and number of files stored per client
SELECT node_name,CAST(FLOAT(SUM(physical_mb)) / 1024 AS DEC(8,2))as "Space in GB", SUM(num_files)as"Number of files" FROM occupancy GROUP BY node_name

#--- Data stored per client (GB)
SELECT node_name,CAST(FLOAT(SUM(logical_mb)) / 1024 AS DEC(8,2))"Space en Go" FROM occupancy GROUP BY node_name

#--- Management classes with backup copy group information
SELECT mgmtclasses.domain_name, mgmtclasses.set_name, mgmtclasses.class_name, mgmtclasses.defaultmc, bu_copygroups.verexists, bu_copygroups.verdeleted, bu_copygroups.retextra, bu_copygroups.retonly, bu_copygroups.destination FROM mgmtclasses mgmtclasses, bu_copygroups bu_copygroups WHERE mgmtclasses.domain_name = bu_copygroups.domain_name AND mgmtclasses.set_name = bu_copygroups.set_name AND mgmtclasses.class_name = bu_copygroups.class_name AND mgmtclasses.set_name=#ACTIVE# ORDER BY mgmtclasses.domain_name, mgmtclasses.set_name, mgmtclasses.class_name

#--- Management classes with archive copy group information
SELECT mgmtclasses.domain_name, mgmtclasses.set_name, mgmtclasses.class_name, mgmtclasses.defaultmc, ar_copygroups.retver, ar_copygroups.destination FROM mgmtclasses mgmtclasses, ar_copygroups ar_copygroups WHERE mgmtclasses.domain_name = ar_copygroups.domain_name AND mgmtclasses.set_name = ar_copygroups.set_name AND mgmtclasses.class_name = ar_copygroups.class_name AND mgmtclasses.set_name=#ACTIVE# ORDER BY mgmtclasses.domain_name, mgmtclasses.set_name, mgmtclasses.class_name

#--- Destination pool of each management class (type: archive copy group)
SELECT domain_name, class_name, destination FROM ar_copygroups

#--- Destination pool of each management class (type: backup copy group)
SELECT domain_name, class_name, destination FROM bu_copygroups WHERE set_name=#ACTIVE#

#--- Some information about archive copy group active
SELECT domain_name,set_name,class_name,retver,destination FROM ar_copygroups where set_name=#ACTIVE#

#--- Some information about backup copy group active
SELECT domain_name,set_name,class_name,retver,destination FROM ar_copygroups where set_name=#ACTIVE#

#--- Niveau Seuil Reclaim 
SELECT stgpool_name,pooltype,devclass,collocate,reclaim FROM stgpools

#
#===============================
#-- Volumes
#===============================
#
#--- Number of scratch volumes by library
SELECT library_name,COUNT(StAr) as "Nombre de Scratch" FROM libvolumes WHERE status=#Scratch# GROUP BY library_name

#--- Number of volumes to reclaim
SELECT volume_name,PCT_RECLAIM from volumes where stgpool_name=#STG_CIMAFAP_COPY_PRA_OLD# and PCT_RECLAIM !< 85

#--- Number of volumes per device class
SELECT devclass_name, COUNT(StAr)"Nombre de Scratch" FROM volumes GROUP BY devclass_name

#--- Number of volumes per storage pool
SELECT stgpool_name,COUNT(StAr)"Nombre de Volumes" FROM volumes GROUP BY stgpool_name

#--- Volumes with write or read errors in the library
SELECT volumes.volume_name, volumes.stgpool_name, volumes.pct_utilized, volumes.status, volumes.write_errors, volumes.read_errors FROM volumes, libvolumes WHERE  volumes.volume_name=libvolumes.volume_name AND ( volumes.write_errors>0 OR volumes.read_errors>0 )

#--- Volume information ordered by (%) reclaim
SELECT volume_name,devclass_name,stgpool_name,pct_reclaim,pct_utilized,status,access FROM volumes order by pct_reclaim

#--- Number of tapes per storage pool in the library
SELECT volumes.stgpool_name, count(StAr)"Nombre Volumes" FROM volumes, libvolumes WHERE  volumes.volume_name=libvolumes.volume_name GROUP BY stgpool_name

#--- Number of volumes in the library per owner
SELECT owner,count(StAr)"Nombre Volumes" FROM libvolumes WHERE status<>#Scratch# GROUP BY owner

#--- Maximum scratch volumes allowed and number of volumes used per stgpool
SELECT stgpool_name,devclass,maxscratch,numscratchused FROM stgpools

#--- Number of full tsm db backups in the last 24 hours
SELECT COUNT(StAr)"Nombre Backups" FROM volhistory WHERE type=#BACKUPFULL# AND date_time>=current_timestamp-24 hours
SELECT date_time, type, backup_series, volume_seq, devclass, volume_name FROM volhistory WHERE ( type=#BACKUPFULL# OR type=#BACKUPINCR# OR type=#DBSNAPSHOT# ) AND date_time>=current_timestamp-28 hours

#
#===============================
#-- DRM
#===============================
#
#--- Information about drm volumes
SELECT drmedia.volume_name, volumes.stgpool_name, drmedia.state, drmedia.voltype, volumes.status, volumes.pct_utilized FROM drmedia, volumes WHERE drmedia.volume_name=volumes.volume_name ORDER BY drmedia.state

#--- Number of Volumes per DRM State
SELECT state,count(StAr) as "Number of volumes" FROM drmedia GROUP BY state

#---- Liste Bandes STG pret a etre reclamer si baisse seuil
SELECT volume_name,PCT_RECLAIM,LAST_WRITE_DATE,stgpool_name from volumes where PCT_RECLAIM !< 85

@EOFF
